.. _config:

=============
Configuration
=============

.. toctree::
   :maxdepth: 2

   config-address-scopes
   config-services-agent
   config-auto-allocation
   config-az
   config-bgp-dynamic-routing
   config-bgp-floating-ip-over-l2-segmented-network
   config-dhcp-ha
   config-dns-int
   config-dns-int-ext-serv
   config-dns-res
   config-dvr-ha-snat
   config-experimental-framework
   config-fip-port-forwardings
   config-ipam
   config-ipv6
   config-macvtap
   config-metadata-caching
   config-metadata-rate-limiting
   config-ml2
   config-mtu
   config-ndp-proxy
   config-network-segment-ranges
   config-ovs-dpdk
   config-ovs-offload
   config-ovsfwdriver
   config-logging
   config-qos
   config-qos-min-bw
   config-qos-min-pps
   config-rbac
   config-routed-networks
   config-sriov
   config-sfc
   config-service-subnets
   config-subnet-onboard
   config-subnet-pools
   config-trunking
   config-wsgi

.. note::

   For general configuration, see the `Configuration Reference
   <../configuration/>`_.
